@@ -21,15 +21,14 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <stdarg.h>
 
 #include "unittest.h"
-
-#include "display.h"
-#include "functions.h"
-#include "calctool.h"
 #include "mp-equation.h"
 
+static MPEquationOptions options;
+
 static int fails = 0;
 
 /* If we're not using GNU C, elide __attribute__ */
@@ -68,12 +67,12 @@ test(char *expression, char *expected, int expected_error)
 {
     int error;
     MPNumber result;
-    char result_str[MAXLINE] = "";
+    char result_str[1024] = "";
     
-    error = mp_equation_parse(expression, &result);
+    error = mp_equation_parse(expression, &options, &result);
 
     if(error == 0) {
-        mp_cast_to_string(&result, basevals[v->base], 9, 1, result_str, MAXLINE);
+        mp_cast_to_string(&result, options.base, 9, 1, result_str, 1024);
         if(expected_error != 0)
             fail("'%s' -> %s, expected error %d", expression, result_str, expected_error);
         else if(strcmp(result_str, expected) != 0)
@@ -93,17 +92,18 @@ test(char *expression, char *expected, int expected_error)
 void
 test_parser()
 {
-    v->ttype = MP_DEGREES;
-    v->wordlen = 32;
-    v->accuracy = 9;
+    memset(&options, 0, sizeof(options));
+    options.base = 10;
+    options.wordlen = 32;
+    options.angle_units = MP_DEGREES;
 
-    v->base = BIN;
+    options.base = 2;
     test("0", "0", 0);
     test("1", "1", 0);
     test("10", "10", 0);
     test("210", "", -1);
 
-    v->base = OCT;
+    options.base = 8;
     test("0", "0", 0);
     test("1", "1", 0);
     test("2", "2", 0);
@@ -115,7 +115,7 @@ test_parser()
     test("76543210", "76543210", 0);
     test("876543210", "", -1);
     
-    v->base = DEC;
+    options.base = 10;
     test("0", "0", 0);
     test("1", "1", 0);
     test("2", "2", 0);
@@ -129,7 +129,7 @@ test_parser()
     test("9876543210", "9876543210", 0);
     test("A9876543210", "", -7);
 
-    v->base = HEX;
+    options.base = 16;
     test("0", "0", 0);
     test("1", "1", 0);
     test("2", "2", 0);
@@ -149,7 +149,7 @@ test_parser()
     test("FEDBCA9876543210", "FEDBCA9876543210", 0);
     test("GFEDBCA9876543210", "", -7);
 
-    v->base = DEC;
+    options.base = 10;
     test("+1", "1", 0);
     test("−1", "−1", 0);
     test("+ 1", "1", 0); // FIXME: Should this be allowed?
@@ -242,8 +242,8 @@ test_parser()
     test("1÷4", "0.25", 0);
     test("1÷3", "0.333333333", 0);
     test("2÷3", "0.666666667", 0);
-    test("1÷0", "", -20001);
-    test("0÷0", "", -20001);
+    test("1÷0", "", -9);
+    test("0÷0", "", -9);
     
     /* Precision */
     test("1000000000000000−1000000000000000", "0", 0);
@@ -270,9 +270,9 @@ test_parser()
     test("1!", "1", 0);
     test("5!", "120", 0);
     test("69!", "171122452428141311372468338881272839092270544893520369393648040923257279754140647424000000000000000", 0);
-    test("0.1!", "", -20001);
+    test("0.1!", "", -9);
     test("−1!", "−1", 0);
-    test("(−1)!", "", -20001);
+    test("(−1)!", "", -9);
     test("−(1!)", "−1", 0);
 
     /* Powers */
@@ -283,7 +283,7 @@ test_parser()
     test("2^1", "2", 0);
     test("2^2", "4", 0);
     test("2⁻¹", "0.5", 0);
-    //test("2⁻", "", -20001); // FIXME: Maybe an error in bison?
+    //test("2⁻", "", -9); // FIXME: Maybe an error in bison?
     test("2^−1", "0.5", 0);
     test("2^(−1)", "0.5", 0);
     test("−10^2", "−100", 0);
@@ -307,7 +307,7 @@ test_parser()
     test("Sqrt(2)", "1.414213562", 0);
     test("4^0.5", "2", 0);
     test("2^0.5", "1.414213562", 0);
-    test("(−4)^0.5", "", -20001);
+    test("(−4)^0.5", "", -9);
     test("(−8)^(1÷3)", "−2", 0);
     
     test("0 mod 7", "0", 0);
@@ -329,8 +329,8 @@ test_parser()
     test("abs 1", "1", 0);
     test("abs −1", "1", 0);
 
-    test("log −1", "", -20001);
-    test("log 0", "", -20001);
+    test("log −1", "", -9);
+    test("log 0", "", -9);
     test("log 1", "0", 0);
     test("log 2", "0.301029996", 0);
     test("log 10", "1", 0);
@@ -338,14 +338,14 @@ test_parser()
     test("log₂ 2", "1", 0);
     test("2 log 2", "0.602059991", 0);
 
-    test("ln −1", "", -20001);
-    test("ln 0", "", -20001);
+    test("ln −1", "", -9);
+    test("ln 0", "", -9);
     test("ln 1", "0", 0);
     test("ln 2", "0.693147181", 0);
     test("ln e", "1", 0);
     test("2 ln 2", "1.386294361", 0);
 
-    v->ttype = MP_DEGREES;
+    options.angle_units = MP_DEGREES;
     test("sin 0", "0", 0);
     test("sin 45 − 1÷√2", "0", 0);
     test("sin 20 + sin(−20)", "0", 0);
@@ -364,7 +364,7 @@ test_parser()
 
     test("tan 0", "0", 0);
     test("tan 10 − sin 10÷cos 10", "0", 0);
-    test("tan 90", "", -20001);
+    test("tan 90", "", -9);
     test("tan 10", "0.176326981", 0);    
     test("tan²10", "0.031091204", 0);
 
@@ -392,20 +392,20 @@ test_parser()
     test("atanh 0", "0", 0);
     test("atanh (1÷10) − 0.5 ln(11÷9)", "0", 0);
 
-    v->ttype = MP_DEGREES;
+    options.angle_units = MP_DEGREES;
     test("sin 90", "1", 0);
     
-    v->ttype = MP_RADIANS;
+    options.angle_units = MP_RADIANS;
     test("sin (π÷2)", "1", 0); // FIXME: Shouldn't need brackets
     
-    v->ttype = MP_GRADIANS;
+    options.angle_units = MP_GRADIANS;
     test("sin 100", "1", 0);
 
     test("3 and 5", "1", 0);
     test("3 or 5", "7", 0);
     test("3 xor 5", "6", 0);
 
-    v->base = HEX;
+    options.base = 16;
     test("ones 1", "FFFFFFFE", 0);
     test("ones 7FFFFFFF", "80000000", 0);
     test("twos 1", "FFFFFFFF", 0);
